@@ -16,7 +16,14 @@ from pathlib import Path  # noqa: E402
 import requests  # noqa: E402
 
 
-from .utils import Reader, load_data, resample_like  # isort:skip  # noqa: E402, F401
+from .utils import (  # isort:skip  # noqa: E402, F401
+    Reader,
+    load_data,
+    resample_like,
+    return_response,
+)
+
+
 from .gateway import Gateway  # isort:skip  # noqa: E402, F401
 from .readers import axds, erddap, local  # isort:skip  # noqa: E402
 
@@ -24,6 +31,7 @@ from .vars import (  # isort:skip  # noqa: F401, E402
     all_variables,
     check_variables,
     search_variables,
+    select_variables,
 )
 
 try:
@@ -85,31 +93,10 @@ keys_kwargs = [
     "stations",
     # "dataset_ids",
     "variables",
+    "criteria",
+    "variables",
+    "var_def",
 ]
 
-
-# For variable identification with cf-xarray
-# custom_criteria to identify variables is saved here
-# https://gist.github.com/kthyng/c3cc27de6b4449e1776ce79215d5e732
-my_custom_criteria_gist = "https://gist.githubusercontent.com/kthyng/c3cc27de6b4449e1776ce79215d5e732/raw/be8409927b8743d4856f553c5639fb82d5a34d6b/my_custom_criteria.py"
-response = requests.get(my_custom_criteria_gist)
-my_custom_criteria = ast.literal_eval(response.text)
-cfxr.set_options(custom_criteria=my_custom_criteria)
-
-# Principle variable list. These variable names need to match those in the gist.
-# units
-# QARTOD numbers for variables
-var_def = {
-    "temp": {
-        "units": "degree_Celsius",
-        "fail_span": [-100, 100],
-        "suspect_span": [-10, 40],
-    },
-    "salt": {"units": "psu", "fail_span": [-10, 60], "suspect_span": [-1, 45]},
-    "u": {"units": "m/s", "fail_span": [-10, 10], "suspect_span": [-5, 5]},
-    "v": {"units": "m/s", "fail_span": [-10, 10], "suspect_span": [-5, 5]},
-    "ssh": {"units": "m", "fail_span": [-10, 10], "suspect_span": [-3, 3]},
-}
-
 # QARTOD defs
 qcdefs = {"4": "FAIL", "1": "GOOD", "9": "MISSING", "3": "SUSPECT", "2": "UNKNOWN"}
